@@ -300,8 +300,6 @@
 ( cd opt/kde/share/doc/HTML/hu/kblackbox ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kcharselect ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kuickshow ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kuickshow ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kiconedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/klettres ; rm -rf common )
